Introduction | MetaboLabPy

# MetaboLabPy

Advanced NMR Data Processing in Python

## Site Navigation[Skip]

- Introduction

## Introduction

MetaboLabPy is a software package for NMR processing written in Python for the Apple macOS, Linux and Windows platforms, currently developed at the University of Birmingham. It contains of a series of processing algorithms for 1D and 2D processing including apodization functions, Fourier transformation and baseline correction. A simple interface is available to set up processing parameters. The current version supports Bruker and Varian file formats.

MetaboLabPy includes routines for Bruker and Varian data, including alignment tools, various scaling algorithms (autoscale, Pareto scaling and glog transform), graphical selection of exclusion regions, bucketing and links to PCA and PLS algorithms.

The software is fully opensource and can be installed via PyPI.

© Christian Ludwig 2020
[Back To Top]